Crate molten_workflow

Crate molten_workflow 

Molten Workflow

molten-workflow provides the workflow state machine engine, transition rules, and workflow management for the Molten Document and Workflow Management system.

This crate is under active development and is not yet stable. If this crate has been abandoned, please message me and we can discuss ownership transfer.

Re-exports

pub use engine::transition;
pub use error::WorkflowError;

Modules

engine
Provides the core workflow engine logic, including the transition function. This module provides the functions which implement the core workflow engine logic.
error
Defines custom error types specific to workflow operations. Defines error types specific to workflow operations within the molten-workflow crate.