Module engine

Module engine 

Provides the core workflow engine logic, including the transition function. This module provides the functions which implement the core workflow engine logic.

Functions

transition
Attempts to transition a document from its current phase to a specified target phase according to the rules defined in the provided workflow.